@@ -1,5 +1,5 @@
 import logging, os, zipfile, hashlib, sys
-from .config import Conf
+from .configuration import Conf
 import json
 from shutil import copyfile
 import requests
@@ -30,27 +30,11 @@ def start(args):
                     fnc = __import__('function')
                     pipeline_key = fnc.Function().pipelines().get_keys()[0]
 
-                    copyfile(os.path.join(dirname, 'assets/pandioml-1.0.5-py3-none-any.whl'),
-                             os.path.join(path, 'deps/pandioml-1.0.5-py3-none-any.whl'))
+                    print("Getting project requirements...")
 
-                    if 'ADMIN_API' in project_config.pandio and 'localhost' in project_config.pandio['ADMIN_API']:
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    -r {dirname}/assets/pandioml_requirements.txt -d {path}/deps")
-
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    -r {path}/requirements.txt -d {path}/deps")
-                    else:
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    --platform manylinux1_x86_64 \
-                                    --python-version 37 -r {dirname}/assets/pandioml_requirements.txt -d {path}/deps")
-
-                        os.system(f"pip download \
-                                    --only-binary :all: \
-                                    --platform manylinux1_x86_64 \
-                                    --python-version 37 -r {path}/requirements.txt -d {path}/deps")
+                    f = open(f"{path}/pandio_requirements.txt", "w")
+                    f.write("pandioml>=1.0.6")
+                    f.close()
 
                     hash = hashlib.md5(bytes(args.project_folder, 'utf-8'))
                     tmp_path = tmp_path + hash.hexdigest() + '/'
@@ -63,6 +47,9 @@ def start(args):
                     zipf.close()
                     print(f"File located at {tmp_path}{tmp_file}")
 
+                    if os.path.exists(f"{path}/deps"):
+                        rmtree(f"{path}/deps")
+
                     arr = {
                         "name": project_config.pandio['FUNCTION_NAME'],
                         "userConfig": {
