@@ -1,21 +1,18 @@
-import pathlib
 import os
-import os.path
-import signal
-import subprocess
 import sys
-from .config import Conf
+from .configuration import Conf
 import hashlib
 from pandioml.core.artifacts import artifact
 import zipfile
 from appdirs import user_config_dir
+import docker
+from shutil import copyfile
+dirname = os.path.dirname(os.path.realpath(__file__))
 
 config = Conf()
 if os.path.exists(user_config_dir('PandioCLI', 'Pandio')+'/config.json'):
     config.load(user_config_dir('PandioCLI', 'Pandio')+'/config.json')
 
-shutdown = False
-
 
 def start(args):
     BUF_SIZE = 65536
@@ -32,6 +29,11 @@ def start(args):
         print(f"{args.project_folder} is invalid.")
         exit()
 
+    path = os.path.join(os.getcwd(), args.project_folder)
+    sys.path.append(path)
+    project_config = __import__('config')
+    artifact.set_storage_location(project_config.pandio['ARTIFACT_STORAGE'])
+
     val = input("Would you like to store artifacts (dataset, pipeline, model, etc.)? If no, only the model will be saved. (y,n): ")
     store = True if val.lower() == 'y' or val.lower() == 'yes' else False
     if store:
@@ -109,18 +111,77 @@ def start(args):
 
     print("Starting execution of pipeline(s).")
 
-    sys.path.insert(1, os.path.join(os.path.abspath(os.path.dirname(__file__)), 'assets'))
-    sys.path.insert(1, os.path.join(os.getcwd(), args.project_folder))
-    pm = __import__('runner')
-    pm.run(args.dataset_name, loops, pipeline_name=pipeline_name)
-
     print("")
 
+    try:
+        client = docker.from_env()
+    except Exception as e:
+        print("There was an error connecting to Docker. Is it installed and started?")
+        print("")
+        print("Get Docker for free at: https://www.docker.com")
+        print("")
+        exit()
 
-def shutdown_callback(signalNumber, frame):
-    global shutdown
-    shutdown = True
+    path = os.path.join(os.getcwd(), args.project_folder)
+    if os.path.exists(os.path.join(os.getcwd(), args.dataset_name, 'dataset.py')):
+        dpath = os.path.join(os.getcwd(), args.dataset_name)
+    else:
+        dpath = None
 
+    copyfile(os.path.join(dirname, 'assets/runner.py'),
+             os.path.join(path, 'runner.py'))
+    copyfile(os.path.join(dirname, 'assets/wrapper.py'),
+             os.path.join(path, 'wrapper.py'))
 
-signal.signal(signal.SIGINT, shutdown_callback)
-signal.signal(signal.SIGTERM, shutdown_callback)
+    dataset_name = args.dataset_name
+
+    volumes = {path: {'bind': '/code', 'mode': 'rw'}}
+    if dpath is not None:
+        dataset_name = '/dataset'
+        volumes[dpath] = {'bind': dataset_name, 'mode': 'rw'}
+
+    client.containers.run('pandio/pandioml', name='pandiocli', volumes=volumes,
+                          detach=True)
+
+    api = docker.APIClient()
+
+    # Install pip requirements for the project
+    if os.path.exists(os.path.join(os.getcwd(), args.project_folder, 'requirements.txt')):
+        f = open(os.path.join(os.getcwd(), args.project_folder, 'requirements.txt'), "r")
+        _reqs = f.read().splitlines()
+
+        if len(_reqs) > 0:
+            print("Installing project requirements.")
+            c = api.exec_create('pip_project', f"pip install {' '.join(_reqs)}",
+                                tty=True)
+            s = api.exec_start(c, stream=True)
+            for line in s:
+                print(line.decode('UTF-8'))
+
+    if dpath is not None and os.path.exists(os.path.join(os.getcwd(), args.dataset_name, 'requirements.txt')):
+        f = open(os.path.join(os.getcwd(), args.dataset_name, 'requirements.txt'), "r")
+        _reqs = f.read().splitlines()
+
+        if len(_reqs) > 0:
+            print("Installing dataset requirements.")
+            c = api.exec_create('pip_dataset', f"pip install {' '.join(_reqs)}",
+                                tty=True)
+            s = api.exec_start(c, stream=True)
+            for line in s:
+                print(line.decode('UTF-8'))
+
+    c = api.exec_create('pandiocli', f"python /code/runner.py --dataset_name {dataset_name} --loops {loops} "
+                                     f"--pipeline_name {pipeline_name} --pipeline_id {artifact.get_pipeline_id()}", tty=True)
+    s = api.exec_start(c, stream=True)
+    for line in s:
+        print(line.decode('UTF-8'))
+
+    os.remove(os.path.join(path, 'runner.py'))
+    os.remove(os.path.join(path, 'wrapper.py'))
+
+    c = client.containers.get('pandiocli')
+    c.remove(force=True)
+
+    artifact.save()
+
+    print("")
